==> nextcloud-25.0.4.tgz: nextcloud/apps/theming/l10n/it.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Questo nome è troppo lungo",
    "The given web address is too long" : "Questo indirizzo web è troppo lungo",
    "The given web address is not a valid URL" : "L'indirizzo web specifico non è un URL valido",
    "The given legal notice address is too long" : "L'indirizzo dell'avviso legale specificato è troppo lungo",
    "The given legal notice address is not a valid URL" : "L'indirizzo delle specifiche note legali non è un URL valido",
    "The given privacy policy address is too long" : "L'indirizzo dello specifico criterio di riservatezza è troppo lungo",
    "The given privacy policy address is not a valid URL" : "L'indirizzo dello specifico criterio di riservatezza non è un URL valido",
    "The given slogan is too long" : "Questo slogan è troppo lungo",
    "The given color is invalid" : "Questo colore non è valido",
    "Saved" : "Salvato",
    "The file was uploaded" : "Il file è stato caricato",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Il file caricato supera la direttiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The file was only partially uploaded" : "Il file è  stato caricato solo parzialmente",
    "No file was uploaded" : "Non è stato caricato alcun file",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Could not write file to disk" : "Impossibile scrivere il file su disco",
    "A PHP extension stopped the file upload" : "Un'estensione PHP ha fermato il caricamento del file",
    "No file uploaded" : "Nessun file caricato",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Stai già utilizzando un tema personalizzato. Le impostazioni dell'applicazione dei temi potrebbero essere sovrascritte.",
    "Theming" : "Tema",
    "Appearance and accessibility" : "Aspetto e accessibilità",
    "Dark theme with high contrast mode" : "Tema scuro con modalità di contrasto elevato",
    "Enable dark high contrast mode" : "Abilita la modalità scuro ad alto contrasto",
    "Similar to the high contrast mode, but with dark colours." : "Simile alla modalità a contrasto elevato, ma con colori scuri.",
    "Dark theme" : "Tema scuro",
    "Enable dark theme" : "Abilita il tema scuro",
    "System default theme" : "Tema predefinito del sistema",
    "Enable the system default" : "Abilita predefinito del sistema",
    "Using the default system appearance." : "Utilizzo dell'aspetto di sistema predefinito.",
    "Dyslexia font" : "Carattere per dislessici",
    "Enable dyslexia font" : "Abilita il carattere per dislessici",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic è un carattere libero progettato per mitigare alcuni dei comuni errori di lettura causati dalla dislessia.",
    "High contrast mode" : "Modalità ad alto contrasto",
    "Enable high contrast mode" : "Abilita la modalità ad alto contrasto",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Una modalità ad alto contrasto per semplificare la tua navigazione. La qualità visiva sarà ridotta per incrementare la chiarezza.",
    "Light theme" : "Tema leggero",
    "Enable the default light theme" : "Abilita il tema leggero predefinito",
    "The default light appearance." : "L'aspetto predefinito del tema leggero.",
    "Legal notice" : "Avviso legale",
    "Privacy policy" : "Criterio di riservatezza",
    "Adjust the Nextcloud theme" : "Modifica il tema di Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "La gestione dei temi rende semplice la personalizzazione dell'aspetto della tua istanza e dei client supportati. Ciò sarà visibile a tutti gli utenti.",
    "Advanced options" : "Opzioni avanzate",
    "Name" : "Nome",
    "Web link" : "Collegamento web",
    "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
    "Slogan" : "Slogan",
    "Color" : "Colore",
    "Logo" : "Logo",
    "Upload new logo" : "Carica nuovo logo",
    "Legal notice link" : "Collegamento avviso legale",
    "Privacy policy link" : "Collegamento criteri di riservatezza",
    "Header logo" : "Logo dell'intestazione",
    "Upload new header logo" : "Carica nuovo logo dell'intestazione",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Carica nuova favicon",
    "User settings" : "Impostazioni utente",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Background" : "Sfondo",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accesso universale è molto importante per noi. Seguiamo gli standard web e cerchiamo di rendere tutto utilizzabile anche senza mouse, e programmi di assistenza come i lettori dello schermo. Il nostro obiettivo è la compatibilità con la {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 a livello AA, con il tema ad alto contrasto anche a livello AAA. ",
    "Change color" : "Cambia colore",
    "Reset to default" : "Ripristina valori predefiniti",
    "Upload" : "Carica",
    "Remove background image" : "Rimuovi immagine di sfondo",
    "Loading preview…" : "Caricamento anteprima...",
    "Admin" : "Amministratore",
    "Name cannot be empty" : "Il nome non può essere vuoto",
    "Open documentation" : "Apri la documentazione",
    "https://…" : "https://…",
    "Login image" : "Immagine di accesso",
    "Upload new login background" : "Carica nuovo sfondo di accesso",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installa l'estensione Imagemagick di PHP con supporto per le immagini SVG per generare automaticamente favicon basate sul logo caricato e sul colore.",
    "Pick from Files" : "Scegli da File",
    "Custom color" : "Colore personalizzato",
    "Plain background" : "Sfondo semplice",
    "Insert from {productName}" : "Inserisci da {productName}"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-25.0.8.tgz: nextcloud/apps/theming/l10n/it.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Questo nome è troppo lungo",
    "The given web address is too long" : "Questo indirizzo web è troppo lungo",
    "The given web address is not a valid URL" : "L'indirizzo web specifico non è un URL valido",
    "The given legal notice address is too long" : "L'indirizzo dell'avviso legale specificato è troppo lungo",
    "The given legal notice address is not a valid URL" : "L'indirizzo delle specifiche note legali non è un URL valido",
    "The given privacy policy address is too long" : "L'indirizzo dello specifico criterio di riservatezza è troppo lungo",
    "The given privacy policy address is not a valid URL" : "L'indirizzo dello specifico criterio di riservatezza non è un URL valido",
    "The given slogan is too long" : "Questo slogan è troppo lungo",
    "The given color is invalid" : "Questo colore non è valido",
    "Disable-user-theming should be true or false" : "Disattiva-temi-utente deve essere true o false",
    "Saved" : "Salvato",
    "The file was uploaded" : "Il file è stato caricato",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Il file caricato supera la direttiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The file was only partially uploaded" : "Il file è  stato caricato solo parzialmente",
    "No file was uploaded" : "Non è stato caricato alcun file",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Could not write file to disk" : "Impossibile scrivere il file su disco",
    "A PHP extension stopped the file upload" : "Un'estensione PHP ha fermato il caricamento del file",
    "No file uploaded" : "Nessun file caricato",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Stai già utilizzando un tema personalizzato. Le impostazioni dell'applicazione dei temi potrebbero essere sovrascritte.",
    "Theming" : "Tema",
    "Appearance and accessibility" : "Aspetto e accessibilità",
    "Dark theme with high contrast mode" : "Tema scuro con modalità di contrasto elevato",
    "Enable dark high contrast mode" : "Abilita la modalità scuro ad alto contrasto",
    "Similar to the high contrast mode, but with dark colours." : "Simile alla modalità a contrasto elevato, ma con colori scuri.",
    "Dark theme" : "Tema scuro",
    "Enable dark theme" : "Abilita il tema scuro",
    "System default theme" : "Tema predefinito del sistema",
    "Enable the system default" : "Abilita predefinito del sistema",
    "Using the default system appearance." : "Utilizzo dell'aspetto di sistema predefinito.",
    "Dyslexia font" : "Carattere per dislessici",
    "Enable dyslexia font" : "Abilita il carattere per dislessici",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic è un carattere libero progettato per mitigare alcuni dei comuni errori di lettura causati dalla dislessia.",
    "High contrast mode" : "Modalità ad alto contrasto",
    "Enable high contrast mode" : "Abilita la modalità ad alto contrasto",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Una modalità ad alto contrasto per semplificare la tua navigazione. La qualità visiva sarà ridotta per incrementare la chiarezza.",
    "Light theme" : "Tema leggero",
    "Enable the default light theme" : "Abilita il tema leggero predefinito",
    "The default light appearance." : "L'aspetto predefinito del tema leggero.",
    "Legal notice" : "Avviso legale",
    "Privacy policy" : "Criterio di riservatezza",
    "Adjust the Nextcloud theme" : "Modifica il tema di Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "La gestione dei temi rende semplice la personalizzazione dell'aspetto della tua istanza e dei client supportati. Ciò sarà visibile a tutti gli utenti.",
    "Advanced options" : "Opzioni avanzate",
    "Name" : "Nome",
    "Web link" : "Collegamento web",
    "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
    "Slogan" : "Slogan",
    "Color" : "Colore",
    "Logo" : "Logo",
    "Upload new logo" : "Carica nuovo logo",
    "Legal notice link" : "Collegamento avviso legale",
    "Privacy policy link" : "Collegamento criteri di riservatezza",
    "Header logo" : "Logo dell'intestazione",
    "Upload new header logo" : "Carica nuovo logo dell'intestazione",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Carica nuova favicon",
    "User settings" : "Impostazioni utente",
    "Disable user theming" : "Disattiva temi utente",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Sebbene tu possa selezionare e personalizzare la tua istanza, gli utenti possono cambiare il loro sfondo e colore. Se vuoi forzare la tua personalizzazione, puoi attivare questo.",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Background" : "Sfondo",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accesso universale è molto importante per noi. Seguiamo gli standard web e cerchiamo di rendere tutto utilizzabile anche senza mouse, e programmi di assistenza come i lettori dello schermo. Il nostro obiettivo è la compatibilità con la {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 a livello AA, con il tema ad alto contrasto anche a livello AAA. ",
    "Change color" : "Cambia colore",
    "Reset to default" : "Ripristina valori predefiniti",
    "Upload" : "Carica",
    "Remove background image" : "Rimuovi immagine di sfondo",
    "Loading preview…" : "Caricamento anteprima...",
    "Admin" : "Amministratore",
    "Name cannot be empty" : "Il nome non può essere vuoto",
    "Pick from Files" : "Scegli da File",
    "Custom color" : "Colore personalizzato",
    "Plain background" : "Sfondo semplice",
    "Insert from {productName}" : "Inserisci da {productName}",
    "Open documentation" : "Apri la documentazione",
    "https://…" : "https://…",
    "Upload new login background" : "Carica nuovo sfondo di accesso",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Sebbene tu possa selezionare e personalizzare la tua istanza, gli utenti possono cambiare il loro sfondo e colore. Se vuoi forzare la tua personalizzazione, puoi attivare questa casella.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installa l'estensione Imagemagick di PHP con supporto per le immagini SVG per generare automaticamente favicon basate sul logo caricato e sul colore."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
